@@ -391,7 +391,7 @@ class Owner(models.Model):
             self._store_raw_data('structures', structures, corporation_id)
 
         return structures
-
+    
     @staticmethod
     def _compress_services_localization(
         structures_w_lang: dict, default_lang: str
@@ -399,13 +399,22 @@ class Owner(models.Model):
         """compress service names localizations for each structure
         We are assuming that services are returned from ESI in the same order 
         for each language.
-        """
-        
-        # collect services with name localizations for all structures
+        """                
+        structures_services = Owner._collect_services_with_localizations(
+            structures_w_lang, default_lang
+        )        
+        structures = Owner._condense_services_localizations_into_structures(
+            structures_w_lang, default_lang, structures_services
+        )        
+        return structures
+
+    @staticmethod
+    def _collect_services_with_localizations(structures_w_lang, default_lang):
+        """collect services with name localizations for all structures"""
         structures_services = dict()
-        for lang, objects in structures_w_lang.items():            
+        for lang, structures in structures_w_lang.items():
             if lang != default_lang:
-                for structure in objects:
+                for structure in structures:
                     if 'services' in structure and structure['services']:
                         structure_id = structure['structure_id']
                         if structure_id not in structures_services:
@@ -415,20 +424,27 @@ class Owner(models.Model):
                             structures_services[structure_id][lang].append(
                                 service['name']
                             )
+        return structures_services
 
-        # add corresponding service name localizations to structure's services
+    @staticmethod
+    def _condense_services_localizations_into_structures(
+        structures_w_lang, default_lang, structures_services
+    ):
+        """add corresponding service name localizations to structure's services"""
         structures = structures_w_lang[default_lang]
         for structure in structures:
             if 'services' in structure and structure['services']:
                 structure_id = structure['structure_id']
                 for lang in structures_w_lang.keys():
-                    if lang != default_lang:
+                    if (
+                        lang != default_lang 
+                        and lang in structures_services[structure_id]
+                    ):
                         for service, name_loc in zip(
                             structure['services'], 
                             structures_services[structure_id][lang]
                         ):
                             service['name_' + lang] = name_loc
-        
         return structures
 
     def _fetch_custom_offices(self, esi_client: object) -> list:
